//////////////////////////////////////////////////////////////////////////
//
// Conventions:
//
// +x = left
// +z = rear
// +y = up
// +pitch = nose up
// +yaw = nose right
// +roll = right
//
// [BODY]  - a rigid mass with mass and inertial properties
// [JOINT] - a ball joint constraining an offset of one body to an
//           offset of another body (eliminates 3 DOF)
// [HINGE] - a constraint restricting the relative rotations of two
//           bodies to be around a single axis (eliminates 2 DOF).
// [BAR]   - a constraint holding an offset of one body from an offset of
//           another body at a fixed distance (eliminates 1 DOF).
// [JOINT&HINGE] - both the joint and hinge constraints, forming the
//           conventional definition of a hinge (eliminates 5 DOF).
//
//////////////////////////////////////////////////////////////////////////

// Body including all rigidly attached parts (wings, barge boards, etc.)
[BODY]
name=body mass=(698.0) inertia=(826,924,192)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

// Front spindles
[BODY]
name=fl_spindle mass=(15.5) inertia=(0.0275,0.0260,0.0245)
pos=(0.660,0.0,-1.38) ori=(0.0,0.0,0.0)

[BODY]
name=fr_spindle mass=(15.5) inertia=(0.0275,0.0260,0.0245)
pos=(-0.660,0.0,-1.38) ori=(0.0,0.0,0.0)

// Front wheels
[BODY]
name=fl_wheel mass=(22.0) inertia=(1.292,0.724,0.724)
pos=(0.690,0.0,-1.38) ori=(0.0,0.0,0.0)

[BODY]
name=fr_wheel mass=(22.0) inertia=(1.292,0.724,0.724)
pos=(-0.690,0.0,-1.38) ori=(0.0,0.0,0.0)

// NASCAR stock car rear axle (this also contains the mass and inertia of the
// I-beams or torque tube because they are rigidly attached).
[BODY]
name=rear_axle mass=(85.00) inertia=(2.000,2.000,0.950)
pos=(0.0,-0.04,0.95) ori=(0.0,0.0,0.0)

// Rear wheels (includes half of rear-axle)
[BODY]
name=rl_wheel mass=(26.0) inertia=(1.446,0.875,0.875)
pos=(0.675,0.0,1.04) ori=(0.0,0.0,0.0)

[BODY]
name=rr_wheel mass=(26.0) inertia=(1.446,0.875,0.875)
pos=(-0.675,0.0,1.04) ori=(0.0,0.0,0.0)

// Fuel in tank is not rigidly attached - it is attached with springs and
// dampers to simulate movement.  Properties are defined in the HDV file.
[BODY]
name=fuel_tank mass=(5.0) inertia=(1.0,1.0,1.0)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

// Driver's head is not rigidly attached, and it does NOT affect the vehicle
// physics.  Position is from the eyepoint defined in the VEH file, while
// other properties are defined in the head physics file.
[BODY]
name=driver_head mass=(5.0) inertia=(0.02,0.02,0.02)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

//////////////////////////////////////////////////////////////////////////
//
// Constraints
//
//////////////////////////////////////////////////////////////////////////

// Front wheel and spindle connections
[JOINT&HINGE]
posbody=fl_wheel negbody=fl_spindle pos=fl_wheel axis=(-1,0.0,0.0)

[JOINT&HINGE]
posbody=fr_wheel negbody=fr_spindle pos=fr_wheel axis=(1,0.0,0.0)

// Front left suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm
name=fl_fore_upper posbody=body negbody=fl_spindle pos=(0.386,0.235,-1.474) neg=(0.580,0.250,-1.399)

[BAR] // rearward upper arm
posbody=body negbody=fl_spindle pos=(0.386,0.235,-1.285) neg=(0.580,0.250,-1.375)

[BAR] // forward lower arm
posbody=body negbody=fl_spindle pos=(0.345,-0.125,-1.474) neg=(0.612,-0.130,-1.404)

[BAR] // rearward lower arm
name=fl_fore_lower posbody=body negbody=fl_spindle pos=(0.336,-0.125,-1.285) neg=(0.610,-0.130,-1.375)

[BAR] // steering arm (must be named for identification)
name=fl_steering posbody=body negbody=fl_spindle pos=(0.255,-0.060,-1.555) neg=(0.590,-0.025,-1.555)

// Front right suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm (used in steering lock calculation)
name=fr_fore_upper posbody=body negbody=fr_spindle pos=(-0.386,0.235,-1.474) neg=(-0.580,0.250,-1.399)

[BAR] // rearward upper arm
posbody=body negbody=fr_spindle pos=(-0.386,0.235,-1.285) neg=(-0.580,0.250,-1.375)

[BAR] // forward lower arm
name=fr_fore_lower posbody=body negbody=fr_spindle pos=(-0.345,-0.125,-1.474) neg=(-0.612,-0.130,-1.404)

[BAR] // rearward lower arm
posbody=body negbody=fr_spindle pos=(-0.336,-0.125,-1.285) neg=(-0.610,-0.130,-1.375)

[BAR] // steering arm (must be named for identification)
name=fr_steering posbody=body negbody=fr_spindle pos=(-0.255,-0.060,-1.555) neg=(-0.590,-0.025,-1.555)


// Beam axle rear suspension geometry:


// The torque tube is connected to the body with a ball joint 
// in front of the rear axle.
[JOINT]
posbody=body negbody=rear_axle pos=(0.0, -0.06, -0.55)

// Track bar (heights will be changed with track bar adjustments)
[BAR]
posbody=body negbody=rear_axle pos=(-0.55, 0.0, 1.19) neg=(0.55, 0.0, 1.14)

// Rear spindle and wheel connections (axis will be changed with rear camber adjustments)
[JOINT&HINGE]
posbody=rl_wheel negbody=rear_axle pos=rl_wheel axis=(-1.0,0.0,0.0)

[JOINT&HINGE]
posbody=rr_wheel negbody=rear_axle pos=rr_wheel axis=(1.0,0.0,0.0)

